#include <WScom.h>
#include <WSCfunctionList.h>
#include <WSCbase.h>

/**/

#include "Common.h"

/**/

//----------------------------------------------------------
//Function for the event procedure
//----------------------------------------------------------
void CnfNewPush(WSCbase* object){
  //do something...
	WSCstring name = Cnfvifi_Name->getProperty( WSNlabelString );
	WSCstring url = Cnfvifi_Url->getProperty( WSNlabelString );
	bool flagDown = Cnfvtog_Download->getStatus();
	long encoding = ConvStrToEncoding(
		Cnfcomb_Encoding->getProperty( WSNlabelString ) );
	long skipArt = Cnfvsli_SkipArt->getProperty( WSNvalue );

	gHeadLine.AddUrlList( name, url, flagDown, encoding, skipArt );

	Cnfcomb_NameList->setProperty( WSNmenuItems, gUrl.GetList() );
	Cnfcomb_NameList->setProperty( WSNlabelString, name );

	Cnfcomb_NameList->execProcedure( "CnfNameListSelect" );
}
static WSCfunctionRegister  op("CnfNewPush",(void*)CnfNewPush);
